Index: views/views_delegate.h |
diff --git a/views/views_delegate.h b/views/views_delegate.h |
index 13baff03a640a0b6680cc83b21d33880decd9dd7..4b032c317e4ee6ad4b640f8213c0769e094eaade 100644 |
--- a/views/views_delegate.h |
+++ b/views/views_delegate.h |
@@ -12,6 +12,7 @@ |
#endif |
#include "ui/base/accessibility/accessibility_types.h" |
+#include "ui/base/ui_base_types.h" |
#include "views/views_export.h" |
namespace gfx { |
@@ -46,22 +47,19 @@ class VIEWS_EXPORT ViewsDelegate { |
// TODO(beng): perhaps this should be a Widget. |
virtual View* GetDefaultParentView() = 0; |
// Saves the position, size and maximized state for the window with the |
// specified name. |
virtual void SaveWindowPlacement(const Widget* widget, |
const std::wstring& window_name, |
const gfx::Rect& bounds, |
- bool maximized) = 0; |
- |
- // Retrieves the saved position and size for the window with the specified |
- // name. |
- virtual bool GetSavedWindowBounds(const std::wstring& window_name, |
- gfx::Rect* bounds) const = 0; |
- |
- // Retrieves the saved maximized state for the window with the specified |
- // name. |
- virtual bool GetSavedMaximizedState(const std::wstring& window_name, |
- bool* maximized) const = 0; |
+ ui::WindowShowState show_state) = 0; |
+ |
+ // Retrieves the saved position and size and "show" state for the window with |
+ // the specified name. |
+ virtual bool GetSavedWindowPlacement( |
+ const std::wstring& window_name, |
+ gfx::Rect* bounds, |
+ ui::WindowShowState* show_state) const = 0; |
virtual void NotifyAccessibilityEvent( |
views::View* view, ui::AccessibilityTypes::Event event_type) = 0; |
@@ -46,22 +47,19 @@ class VIEWS_EXPORT ViewsDelegate { |
// TODO(beng): perhaps this should be a Widget. |
virtual View* GetDefaultParentView() = 0; |
- // Saves the position, size and maximized state for the window with the |
+ // Saves the position, size and "show" state for the window with the |
// specified name. |
virtual void SaveWindowPlacement(const Widget* widget, |